@@ -35,6 +35,7 @@ class OSP(jaVisa):
     def Get_SW_SP6T(self,slot=11,sw=1):
         """ Slot, Switch """
         # ROUT:CLOS? (@F01A11(0161))
+        CurrState = 1000                    # default test value
         for pos in range(0,7):
             state = self.queryInt(f'ROUT:CLOS? (@F01A{slot:02d}({pos:02d}{sw:02d}))')
             if state == 1:
@@ -47,7 +48,10 @@ class OSP(jaVisa):
             F01Mxx --> F01A1x nomenclature
             ON OFF 1 0
         """
-        self.write(f'CONF:COMP {sState}')
+        if sState in (1,'1','ON'):
+            self.write(f'CONF:COMP ON')
+        elif sState in (0,'0','OFF'):
+            self.write(f'CONF:COMP OFF')
 
     def Set_SW(self,slot=11,sw=1,pos=1):
         # ROUT:CLOS (@F01A11(0161))
