@@ -1,9 +1,6 @@
 # -*- coding: future_fstrings -*-
 ###############################################################################
-### Rohde & Schwarz Automation for demonstration use.
 ### Purpose: OTA ATS1000 Functions
-### Author : Martin C Lim
-### Date   : 20xx.xx.xx
 ###  _____  _____   ____ _______ ____ _________     _______  ______
 ### |  __ \|  __ \ / __ \__   __/ __ \__   __\ \   / /  __ \|  ____|
 ### | |__) | |__) | |  | | | | | |  | | | |   \ \_/ /| |__) | |__
@@ -18,7 +15,7 @@
 ###             \__,_|_| |_|\__\___||___/\__\___|\__,_|
 ###
 ### Terms:  Azimuth:    Θθ; Theta; Turntable;
-###         Elevation:  Φφ; Phi; ATS1000 Arm;
+###         Elevation:  Φφ; Phi; Arm;
 ### OTA:    ATS1000     Great Circle Cut; Turntable & Elevation Arm
 ###############################################################################
 # import time
@@ -31,7 +28,6 @@ class OTA(OTA):
         self.Model = "ATS1000"
         self.EOL   = '\x00'
 
-
     #####################################################################
     ### OTA Get Functions
     #####################################################################
@@ -59,10 +55,6 @@ class OTA(OTA):
     def Get_ElevateSpeed(self):
         return 'TBD'
 
-    def Get_IDN(self):
-        rdStr = self.query(f'*IDN?')
-        return rdStr
-
     def Get_SysStat(self):
         return 'TBD'
 
