@@ -241,9 +241,9 @@ class RCT(RCT):
     def Get_5GNR_FreqRange(self):
         return "HIGH"
 
-    # def Get_5GNR_RefA(self):
-    #     rdStr = '<notRead>'
-    #     return rdStr
+    def Get_5GNR_RefA(self):
+        rdStr = '<notRead>'
+        return rdStr
 
 
     def Get_5GNR_Params(self,amp,swp,sys,trc,header=0):                 #pylint: disable=R0913
@@ -310,7 +310,7 @@ class RCT(RCT):
         return outStr
 
     def Get_5GNR_PhaseCompensate_Freq(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:MEV:PCOM?').split(',')[1]
+        rdStr = self.queryIntArry(f'CONF:NRMM:MEAS:MEV:PCOM?')[1]
         return rdStr
 
     def Get_5GNR_TransPrecoding(self):
@@ -439,7 +439,7 @@ class RCT(RCT):
             self.sdir = "DL"
             self.alloc = 1         #Alloc 0:Coreset 1:PDSCH
         else:
-            print("Set_5GNR_Direction must be UP or DOWN")
+            if self.debug: print("Set_5GNR_Direction must be UP or DOWN")
 
     def Set_5GNR_EVM_AvgCount(self, avg):
         """1 to 1000 slots"""
@@ -452,6 +452,9 @@ class RCT(RCT):
         else:
             self.write(f'CONF:NRMM:MEAS:MEV:MOEX OFF')
 
+    def Set_5GNR_FreqRange(self, state):
+        pass
+
     def Set_5GNR_Path(self,path):
         """string P1.RRH.RF1 P1.RRH.RF2 """
         self.write(f':ROUT:NRMM:MEAS:SPAT "{path}"')
