@@ -63,7 +63,7 @@ class VSA(jaVisa):
 
     def Get_EVM(self):
         #EVM = self.query('FETC:SUMM:EVM:ALL:AVER?')
-        out = self.queryFloat('FETC:SUMM:EVM?;*WAI').strip()
+        out = self.queryFloat('FETC:SUMM:EVM?;*WAI')
         return out
 
     def Get_Freq(self):
@@ -195,7 +195,7 @@ class VSA(jaVisa):
         outStr += self.Get_Params_Sweep(header)+"," if (swp==1) else ""
         outStr += self.Get_Params_System(header)+","if (sys==1) else ""
         outStr += self.Get_Params_Trace(header)+"," if (trc==1) else ""
-        return outStr
+        return outStr[0:-1]
 
     def Get_Params_Amp(self,header=0):
         """Retrieve Parameters for test logs"""
@@ -208,12 +208,21 @@ class VSA(jaVisa):
             outStr = 'Attn,PreAmp,RefLvl'
         return outStr
 
-    def Get_Params_EVM(self):
-        MAttn   = self.Get_AttnMech()
-        RefLvl  = self.Get_RefLevel()
-        Power   = self.Get_ChPwr()
-        EVM     = self.Get_EVM()
-        return f"{MAttn:.2f},{RefLvl:.2f},{Power:6.2f},{EVM:.2f}"
+    def Get_Params_MkrBand(self,header=0):
+        """Retrieve Parameters for test logs"""
+        if header != 1:
+            BndMkr  = self.Get_Mkr_Band()
+            outStr  = f'{BndMkr[0]:.0f},{BndMkr[1]:.3f}'
+        else:
+            outStr = 'MkrFreq,MkrBndPwr'
+        return outStr
+
+    # def Get_Params_EVM(self):
+    #     MAttn   = self.Get_AttnMech()
+    #     RefLvl  = self.Get_RefLevel()
+    #     Power   = self.Get_ChPwr()
+    #     EVM     = self.Get_EVM()
+    #     return f"{MAttn:.2f},{RefLvl:.2f},{Power:6.2f},{EVM:.2f}"
 
     def Get_Params_Sweep(self,header=0):
         # SwpTime,SwpPts,SwpType,SwpOpt,
@@ -471,9 +480,9 @@ class VSA(jaVisa):
         """Hz"""
         self.write(':SENS:FREQ:STAR %f'%fFreq)
 
-    def Set_FreqStep(self,fFreq):
-        """Hz"""
-        self.write(':SENS:FREQ:STEP %f'%fFreq)
+    # def Set_FreqStep(self,fFreq):
+    #     """Hz"""
+    #     self.write(':SENS:FREQ:STEP %f'%fFreq)
 
     def Set_FreqStop(self,fFreq):
         """Hz"""
@@ -687,11 +696,11 @@ class VSA(jaVisa):
         #AUTO | SPEed | DYN
         self.write(f':SENS:SWE:OPT {sOpt}')
 
-    def Set_SweepCont(self,iON):
+    def Set_SweepCont(self, sState):
         """0 | 1 """
-        if iON == 1:
+        if sState in (1, '1', 'ON'):
             self.write('INIT:CONT ON')                      #Continuous Sweep
-        else:
+        elif sState in (0, '0', 'OFF'):
             self.write('INIT:CONT OFF')                     #Single Sweep
 
     def Set_SweepPoints(self,iNum):
