@@ -54,7 +54,7 @@ class VSA(VSA):                        #pylint: disable=E0102
         elif rdStr == 'UL':
             self.ldir = "UL"
         else:
-            print('Get_5GNR_Direction Error')
+            if self.debug: print('Get_LTE_Direction Error')
         # print(f'LTE DIRECTION = {self.ldir}')
         return rdStr
 
@@ -135,7 +135,7 @@ class VSA(VSA):                        #pylint: disable=E0102
         self.cc = iCC
 
     def Set_LTE_ChBW(self,iBW):
-        self.write(f':CONF:LTE:{self.ldir}:BW BW{iBW:02d}_00')
+        self.write(f':CONF:LTE:{self.ldir}:CC:BW BW{iBW:d}_00')
 
     def Set_LTE_Direction(self,sDir):
         # UL or DL
