@@ -25,6 +25,11 @@ class VST(object):
         self.FSW = VSA().jav_Open(FSW_IP,OFile)  #Create FSW Object
         return self
 
+    def jav_OpenTest(self,SMW_IP,FSW_IP):
+        self.SMW = VSG().jav_OpenTest(SMW_IP)  #Create SMW Object
+        self.FSW = VSA().jav_OpenTest(FSW_IP)  #Create FSW Object
+        return self
+
     def jav_Close(self):
         self.SMW.jav_Close()
         self.FSW.jav_Close()
