@@ -18,7 +18,7 @@ class VST(object):
         self.Freq      = 2.5e9
         self.SWM_Out  = 0
         self.LTE_Dir    = 'DL'
-        self.LTE_ChBW  = 100        #MHz
+        self.LTE_ChBW   = 5        #MHz
         self.LTE_RB     = 66        #RB
         self.LTE_RBO    = 0         #RB Offset
         self.LTE_Mod    = 'QAM64'   #QPSK; QAM16; QAM64; QAM256
@@ -75,8 +75,13 @@ class VST(object):
                     print("%s\t%s\t%s"%(data[0][i],'<notRead>',data[2][i]))
 
     def jav_Open(self,SMW_IP,FSW_IP,OFile=''):
-        self.SMW = VSG().jav_Open(SMW_IP,OFile,prnt=0)  #Create SMW Object
-        self.FSW = VSA().jav_Open(FSW_IP,OFile,prnt=0)  #Create FSW Object
+        self.SMW = VSG().jav_Open(SMW_IP,OFile)  #Create SMW Object
+        self.FSW = VSA().jav_Open(FSW_IP,OFile)  #Create FSW Object
+        return self
+
+    def jav_OpenTest(self,SMW_IP,FSW_IP):
+        self.SMW = VSG().jav_OpenTest(SMW_IP)  #Create SMW Object
+        self.FSW = VSA().jav_OpenTest(FSW_IP)  #Create FSW Object
         return self
 
     def jav_Close(self):
