@@ -18,7 +18,7 @@ class VST(object):
         self.Freq      = 2.5e9
         self.SWM_Out   = 0
         self.WLAN_Std  = 'N'
-        self.WLAN_ChBW = 100        #MHz
+        self.WLAN_ChBW = 20        #MHz
         self.WLAN_MCS  = 1
         self.WLAN_Mod  = 'QAM64'    #QPSK; QAM16; QAM64; QAM256
 
@@ -71,6 +71,11 @@ class VST(object):
         self.FSW = VSA().jav_Open(FSW_IP,OFile,prnt=0)  #Create FSW Object
         return self
 
+    def jav_OpenTest(self,SMW_IP,FSW_IP):
+        self.SMW = VSG().jav_OpenTest(SMW_IP)  #Create SMW Object
+        self.FSW = VSA().jav_OpenTest(FSW_IP)  #Create FSW Object
+        return self
+
     def jav_Close(self):
         self.SMW.jav_Close()
         self.FSW.jav_Close()
