@@ -13,6 +13,7 @@
 import time
 import visa
 import rssd.FileIO                                #pylint: disable=E0611,E0401
+from rssd.test.yaVISA       import jaVISA_mock      #pylint: disable=E0611,E0401
 
 class jaVisa(object):
     ### Rohde & Schwarz VISA Class
@@ -27,12 +28,13 @@ class jaVisa(object):
         self.EOL        = '\n'
         self.f          = ''    # file log object
         self.dLastErr   = ''
+        self.VISA       = ''    # '@py' for pyvisa-py
         self.K2         = 'NoVISA'
 
     def delay(self,sec):
         time.sleep(sec)
 
-    def jav_Clear(self):
+    def jav_Clear(self):                #pylint:disable=E0202
         self.K2.clear()
 
     def jav_Close(self):
@@ -59,7 +61,7 @@ class jaVisa(object):
             if self.debug: print("jav_ClrErr: %s-->SYST:ERR not Supported"%(self.Model))
         return ErrList
 
-    def jav_Error(self):
+    def jav_Error(self):                                    #pylint: disable=E0202
         RdStr = self.query("SYST:ERR?").strip().split(',')
         return RdStr
 
@@ -119,7 +121,7 @@ class jaVisa(object):
         if self.debug: print('jav_Wai   : %0.2fsec'%(delta))
         return delta
 
-    def jav_Open(self, IPAddr, fily=''):
+    def jav_Open(self, IPAddr, fily=''):                                        #pylint: disable=E0202
         #  VISA: 'TCPIP0::'+IP_Address+'::INSTR'
         #  VISA: 'TCPIP0::'+IP_Address+'::inst0'
         #  VISA: 'TCPIP0::'+IP_Address+'::hislip0'
@@ -139,7 +141,7 @@ class jaVisa(object):
         GPIB::<Addr>::INSTR
         ASRL1::INSTR
         """
-        rm = visa.ResourceManager()                         #Create Resource Manager
+        rm = visa.ResourceManager(self.VISA)                #Create Resource Manager
         #rmList = rm.list_resources()                       #List VISA Resources
         try:
             self.K2 = rm.open_resource(sVISAStr)            #Create Visa Obj
@@ -152,6 +154,22 @@ class jaVisa(object):
             self.K2 = 'NoVISA'
         return self
 
+    def jav_OpenTest(self, host):
+        self.debug = 0
+        self.jav_Open(host)
+        self.connected      = 1
+        if self.K2 == 'NoVISA':
+            mock = jaVISA_mock()
+            self.jav_Open   = mock.jav_Open
+            self.write      = mock.write
+            self.query      = mock.query
+            self.jav_Error  = mock.jav_Error
+            self.jav_Clear  = mock.jav_Clear
+            self.connected  = 0
+        self.jav_ClrErr()
+        self.dLastErr = ""
+        return self
+
     def jav_fileout(self, fily, outstr):
         try:
             if fily != '':
@@ -192,7 +210,7 @@ class jaVisa(object):
                 OutList.append(ReadStr)
         return OutList
 
-    def query(self,cmd):
+    def query(self,cmd):                                    #pylint: disable=E0202
         read ="<notRead>"
         try:
             if self.dataIDN != "":
@@ -214,7 +232,7 @@ class jaVisa(object):
             strArry = self.query(cmd).split(',')
             return [float(i) for i in strArry]
         except:
-            return [-9999.9999]
+            return [-9999.9999, -888.888, -777.777]
 
     def queryInt(self,cmd):
         try:
@@ -229,9 +247,9 @@ class jaVisa(object):
             strArry = self.query(cmd).split(',')
             return [int(i) for i in strArry]
         except:
-            return [-9999]
+            return [-9999,-8888,-7777]
 
-    def write(self,cmd):
+    def write(self,cmd):                                    #pylint: disable=E0202
         try:
             if self.dataIDN != "": self.K2.write(cmd)       #Write if connected
         except:
@@ -240,7 +258,7 @@ class jaVisa(object):
 
 if __name__ == "__main__":
     RS = jaVisa()
-    ipaddress   = '192.168.1.160'
+    ipaddress   = '192.168.1.109'
     port        = 5025
     RS.debug    = 1
     # RS.jav_logscpi()
