@@ -15,7 +15,6 @@ import unittest
 class TestGeneral(unittest.TestCase):
     def setUp(self):                                #Run before each test
         print("",end="")
-        pass
 
     def tearDown(self):                             #Run after each test
         pass
@@ -117,11 +116,6 @@ class TestGeneral(unittest.TestCase):
         self.FSW = VSA()
         self.assertEqual(self.FSW.Model,"FSW")
 
-    def test_VSE_ADemod(self):
-        from rssd.VSE.ADemod import VSE             #pylint:disable=E0611,E0401
-        self.VSE = VSE()        
-        self.assertEqual(self.VSE.Model,"VSE")
-
     def test_VSE_Common(self):
         from rssd.VSE.Common import VSE             #pylint:disable=E0611,E0401
         self.VSE = VSE()        
@@ -197,4 +191,3 @@ if __name__ == '__main__':                          # pragma: no cover
     # unittest.main()     #Run w/o test names
     suite = unittest.TestLoader().loadTestsFromTestCase(TestGeneral)
     unittest.TextTestRunner(verbosity=2).run(suite)
-
